@@ -397,12 +397,15 @@ class SSHClient(object):
         if not self.__ssh.get_transport() or not self.__ssh.get_transport().is_active():
             log.warning(f" {self.__ip}:{self.__port} | SSH连接未激活")
             return False
+        if not self.__sftp:
+            log.info(f" {self.__ip}:{self.__port} | SFTP连接未激活")
+            return False
         try:
             self.__sftp.getcwd()
             log.info(f" {self.__ip}:{self.__port} | SFTP连接已激活")
             return True
         except (paramiko.SSHException, IOError, OSError,Exception) as e:
-            log.error(f" {self.__ip}:{self.__port} | SFTP连接异常: {str(e)}")
+            log.warning(f" {self.__ip}:{self.__port} | SFTP连接异常: {str(e)}")
             return False
 
     def scp_file_to_local(self, remote_path, local_path):
